"""Backward-compatible re-exports for Observatory extension manifest models."""

from phlo.plugins.observatory import (
    ObservatoryExtensionCompatibility,
    ObservatoryExtensionManifest,
    ObservatoryExtensionNavItem,
    ObservatoryExtensionRoute,
    ObservatoryExtensionSettings,
    ObservatoryExtensionSettingsPanel,
    ObservatoryExtensionSlot,
    ObservatoryExtensionUI,
)

__all__ = [
    "ObservatoryExtensionCompatibility",
    "ObservatoryExtensionManifest",
    "ObservatoryExtensionNavItem",
    "ObservatoryExtensionRoute",
    "ObservatoryExtensionSettings",
    "ObservatoryExtensionSettingsPanel",
    "ObservatoryExtensionSlot",
    "ObservatoryExtensionUI",
]
